summaryrefslogtreecommitdiffstats
path: root/ksnapshot
diff options
context:
space:
mode:
Diffstat (limited to 'ksnapshot')
-rw-r--r--ksnapshot/ksnapshot.cpp8
-rw-r--r--ksnapshot/ksnapshot.h6
-rw-r--r--ksnapshot/ksnapshotwidget.ui8
-rw-r--r--ksnapshot/ksnapshotwidget.ui.h2
-rw-r--r--ksnapshot/regiongrabber.cpp16
-rw-r--r--ksnapshot/windowgrabber.cpp46
6 files changed, 43 insertions, 43 deletions
diff --git a/ksnapshot/ksnapshot.cpp b/ksnapshot/ksnapshot.cpp
index 4ed8c110..881f67a2 100644
--- a/ksnapshot/ksnapshot.cpp
+++ b/ksnapshot/ksnapshot.cpp
@@ -26,7 +26,7 @@
#include <tqbitmap.h>
#include <tqdragobject.h>
#include <tqimage.h>
-#include <clipboard.h>
+#include <tqclipboard.h>
#include <tqvbox.h>
#include <kaccel.h>
@@ -162,7 +162,7 @@ bool KSnapshot::save( const KURL& url )
{
if ( KIO::NetAccess::exists( url, false, this ) ) {
const TQString title = i18n( "File Exists" );
- const TQString text = i18n( "<qt>Do you really want to overwrite <b>%1</b>?</qt>" ).arg(url.prettyURL());
+ const TQString text = i18n( "<qt>Do you really want to overwrite <b>%1</b>?</qt>" ).tqarg(url.prettyURL());
if (KMessageBox::Continue != KMessageBox::warningContinueCancel( this, text, title, i18n("Overwrite") ) )
{
return false;
@@ -199,7 +199,7 @@ bool KSnapshot::save( const KURL& url )
TQString caption = i18n("Unable to save image");
TQString text = i18n("KSnapshot was unable to save the image to\n%1.")
- .arg(url.prettyURL());
+ .tqarg(url.prettyURL());
KMessageBox::error(this, text, caption);
}
@@ -241,7 +241,7 @@ void KSnapshot::slotSaveAs()
void KSnapshot::slotCopy()
{
- TQClipboard *cb = TQApplication::clipboard();
+ TQClipboard *cb = TQApplication::tqclipboard();
cb->setPixmap( snapshot );
}
diff --git a/ksnapshot/ksnapshot.h b/ksnapshot/ksnapshot.h
index 1e186b19..c0d5becc 100644
--- a/ksnapshot/ksnapshot.h
+++ b/ksnapshot/ksnapshot.h
@@ -29,7 +29,7 @@ class KSnapshotPreview : public TQLabel
KSnapshotPreview(TQWidget *parent, const char *name = 0)
: TQLabel(parent, name)
{
- setAlignment(AlignHCenter | AlignVCenter);
+ tqsetAlignment(AlignHCenter | AlignVCenter);
setCursor(TQCursor(TQt::PointingHandCursor));
}
virtual ~KSnapshotPreview() {}
@@ -44,14 +44,14 @@ class KSnapshotPreview : public TQLabel
{
TQPainter p(&mask);
- tqstyle().tqdrawPrimitive(TQStyle::PE_SizeGrip, &p, TQRect(0, 0, 15, 15), palette().active());
+ tqstyle().tqdrawPrimitive(TQStyle::PE_SizeGrip, &p, TQRect(0, 0, 15, 15), tqpalette().active());
p.end();
handle.setMask(mask);
}
{
TQPainter p(&handle);
- tqstyle().tqdrawPrimitive(TQStyle::PE_SizeGrip, &p, TQRect(0, 0, 15, 15), palette().active());
+ tqstyle().tqdrawPrimitive(TQStyle::PE_SizeGrip, &p, TQRect(0, 0, 15, 15), tqpalette().active());
p.end();
}
diff --git a/ksnapshot/ksnapshotwidget.ui b/ksnapshot/ksnapshotwidget.ui
index 95590cb4..86e942f2 100644
--- a/ksnapshot/ksnapshotwidget.ui
+++ b/ksnapshot/ksnapshotwidget.ui
@@ -23,7 +23,7 @@
<property name="name">
<cstring>lblImage</cstring>
</property>
- <property name="minimumSize">
+ <property name="tqminimumSize">
<size>
<width>200</width>
<height>130</height>
@@ -107,7 +107,7 @@ If &lt;i&gt;no delay&lt;/i&gt; is set, the program will wait for a mouse click b
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>156</width>
<height>16</height>
@@ -163,7 +163,7 @@ If &lt;i&gt;no delay&lt;/i&gt; is set, the program will wait for a mouse click b
</widget>
<widget class="TQLayoutWidget" row="0" column="3">
<property name="name">
- <cstring>layout1</cstring>
+ <cstring>tqlayout1</cstring>
</property>
<vbox>
<property name="name">
@@ -193,7 +193,7 @@ If &lt;i&gt;no delay&lt;/i&gt; is set, the program will wait for a mouse click b
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>16</width>
<height>16</height>
diff --git a/ksnapshot/ksnapshotwidget.ui.h b/ksnapshot/ksnapshotwidget.ui.h
index 921accc9..601b624f 100644
--- a/ksnapshot/ksnapshotwidget.ui.h
+++ b/ksnapshot/ksnapshotwidget.ui.h
@@ -47,7 +47,7 @@ void KSnapshotWidget::setPreview( const TQPixmap &pm )
TQToolTip::remove( lblImage );
TQToolTip::add( lblImage,
TQString( "Preview of the snapshot image (%1 x %2)" )
- .arg( pm.width() ).arg( pm.height() ) );
+ .tqarg( pm.width() ).tqarg( pm.height() ) );
lblImage->setPixmap( img );
lblImage->adjustSize();
diff --git a/ksnapshot/regiongrabber.cpp b/ksnapshot/regiongrabber.cpp
index f35f61ce..74ac960a 100644
--- a/ksnapshot/regiongrabber.cpp
+++ b/ksnapshot/regiongrabber.cpp
@@ -21,7 +21,7 @@
#include <tqapplication.h>
#include <tqpainter.h>
-#include <palette.h>
+#include <tqpalette.h>
#include <tqstyle.h>
#include <tqtimer.h>
#include <tqtooltip.h>
@@ -41,8 +41,8 @@ SizeTip::SizeTip( TQWidget *parent, const char *name )
void SizeTip::setTip( const TQRect &rect )
{
- TQString tip = TQString( "%1x%2" ).arg( rect.width() )
- .arg( rect.height() );
+ TQString tip = TQString( "%1x%2" ).tqarg( rect.width() )
+ .tqarg( rect.height() );
setText( tip );
adjustSize();
@@ -52,7 +52,7 @@ void SizeTip::setTip( const TQRect &rect )
void SizeTip::positionTip( const TQRect &rect )
{
- TQRect tipRect = geometry();
+ TQRect tipRect = tqgeometry();
tipRect.moveTopLeft( TQPoint( 0, 0 ) );
if ( rect.intersects( tipRect ) )
@@ -61,7 +61,7 @@ void SizeTip::positionTip( const TQRect &rect )
tipRect.moveCenter( TQPoint( deskR.width()/2, deskR.height()/2 ) );
if ( !rect.contains( tipRect, true ) && rect.intersects( tipRect ) )
- tipRect.moveBottomRight( geometry().bottomRight() );
+ tipRect.moveBottomRight( tqgeometry().bottomRight() );
}
move( tipRect.topLeft() );
@@ -92,7 +92,7 @@ void RegionGrabber::initGrabber()
TQDesktopWidget desktopWidget;
TQRect desktopSize;
if ( desktopWidget.isVirtualDesktop() )
- desktopSize = desktopWidget.geometry();
+ desktopSize = desktopWidget.tqgeometry();
else
desktopSize = desktopWidget.screenGeometry( qt_xrootwin() );
@@ -168,8 +168,8 @@ void RegionGrabber::drawRubber()
p.setPen( TQPen( color0, 1 ) );
p.setBrush( NoBrush );
- tqstyle().tqdrawPrimitive( TQStyle::PE_FocusRect, &p, grabRect, colorGroup(),
- TQStyle::Style_Default, TQStyleOption( colorGroup().base() ) );
+ tqstyle().tqdrawPrimitive( TQStyle::PE_FocusRect, &p, grabRect, tqcolorGroup(),
+ TQStyle::Style_Default, TQStyleOption( tqcolorGroup().base() ) );
p.end();
}
diff --git a/ksnapshot/windowgrabber.cpp b/ksnapshot/windowgrabber.cpp
index afc337e5..189fb856 100644
--- a/ksnapshot/windowgrabber.cpp
+++ b/ksnapshot/windowgrabber.cpp
@@ -39,7 +39,7 @@ bool operator< ( const TQRect& r1, const TQRect& r2 )
return r1.width() * r1.height() < r2.width() * r2.height();
}
// Recursively iterates over the window w and its children, thereby building
// a tree of window descriptors. Windows in non-viewable state or with height
// or width smaller than minSize will be ignored.
static
@@ -62,15 +62,15 @@ void getWindowsRecursive( std::vector<TQRect>& windows, Window w,
}
Window root, parent;
- Window* children;
- unsigned int nchildren;
+ Window* tqchildren;
+ unsigned int ntqchildren;
- if( XQueryTree( qt_xdisplay(), w, &root, &parent, &children, &nchildren ) != 0 ) {
- for( unsigned int i = 0; i < nchildren; ++i ) {
- getWindowsRecursive( windows, children[ i ], x, y, depth + 1 );
+ if( XQueryTree( qt_xdisplay(), w, &root, &parent, &tqchildren, &ntqchildren ) != 0 ) {
+ for( unsigned int i = 0; i < ntqchildren; ++i ) {
+ getWindowsRecursive( windows, tqchildren[ i ], x, y, depth + 1 );
}
- if( children != NULL )
- XFree( children );
+ if( tqchildren != NULL )
+ XFree( tqchildren );
}
}
if ( depth == 0 )
@@ -95,16 +95,16 @@ Window findRealWindow( Window w, int depth = 0 )
return w;
}
Window root, parent;
- Window* children;
- unsigned int nchildren;
+ Window* tqchildren;
+ unsigned int ntqchildren;
Window ret = None;
- if( XQueryTree( qt_xdisplay(), w, &root, &parent, &children, &nchildren ) != 0 ) {
+ if( XQueryTree( qt_xdisplay(), w, &root, &parent, &tqchildren, &ntqchildren ) != 0 ) {
for( unsigned int i = 0;
- i < nchildren && ret == None;
+ i < ntqchildren && ret == None;
++i )
- ret = findRealWindow( children[ i ], depth + 1 );
- if( children != NULL )
- XFree( children );
+ ret = findRealWindow( tqchildren[ i ], depth + 1 );
+ if( tqchildren != NULL )
+ XFree( tqchildren );
}
return ret;
}
@@ -143,7 +143,7 @@ TQPixmap grabWindow( Window child, int x, int y, uint w, uint h, uint border )
int count, order;
XRectangle* rects = XShapeGetRectangles( qt_xdisplay(), child,
ShapeBounding, &count, &order );
- //The ShapeBounding region is the outermost shape of the window;
+ //The ShapeBounding region is the outermost tqshape of the window;
//ShapeBounding - ShapeClipping is defined to be the border.
//Since the border area is part of the window, we use bounding
// to limit our work region
@@ -168,7 +168,7 @@ TQPixmap grabWindow( Window child, int x, int y, uint w, uint h, uint border )
//Get the masked away area.
TQRegion maskedAway = bbox - contents;
- TQMemArray<TQRect> maskedAwayRects = maskedAway.rects();
+ TQMemArray<TQRect> maskedAwayRects = maskedAway.tqrects();
//Construct a bitmap mask from the rectangles
TQPainter p(&mask);
@@ -219,12 +219,12 @@ TQPixmap WindowGrabber::grabCurrent( bool includeDecorations )
Window child = windowUnderCursor( includeDecorations );
XGetGeometry( qt_xdisplay(), child, &root, &x, &y, &w, &h, &border, &depth );
Window parent;
- Window* children;
- unsigned int nchildren;
+ Window* tqchildren;
+ unsigned int ntqchildren;
if( XQueryTree( qt_xdisplay(), child, &root, &parent,
- &children, &nchildren ) != 0 ) {
- if( children != NULL )
- XFree( children );
+ &tqchildren, &ntqchildren ) != 0 ) {
+ if( tqchildren != NULL )
+ XFree( tqchildren );
int newx, newy;
Window dummy;
if( XTranslateCoordinates( qt_xdisplay(), parent, qt_xrootwin(),
@@ -339,7 +339,7 @@ int WindowGrabber::windowIndex( const TQPoint &pos ) const
// Draws a border around the (child) window currently containing the pointer
void WindowGrabber::drawBorder()
{
- repaint();
+ tqrepaint();
if ( current >= 0 ) {
TQPainter p;
@@ -39,7 +39,7 @@ bool operator< ( const TQRect& r1, const TQRect& r2 )
return r1.width() * r1.height() < r2.width() * r2.height();
}
-// Recursively iterates over the window w and its children, thereby building
+// Recursively iterates over the window w and its tqchildren, thereby building
// a tree of window descriptors. Windows in non-viewable state or with height
// or width smaller than minSize will be ignored.